@@ -343,8 +343,8 @@ class FingerSvc:
       raise
    def scan(self, deviceID, templateFormat, qualityThreshold):
     try:
-      response = self.stub.Scan(finger_pb2_grpc.finger__pb2.ScanRequest(deviceID=deviceID, templateFormat=templateFormat, qualityThreshold=enrollThreshold))
-      return response.fingerData
+      response = self.stub.Scan(finger_pb2_grpc.finger__pb2.ScanRequest(deviceID=deviceID, templateFormat=templateFormat, qualityThreshold=qualityThreshold))
+      return response
     except grpc.RpcError as e:
       logger.error(f'Cannot scan a finger: {e}')
       raise
